@@ -41,20 +41,21 @@ class ApplicationLoadBalancerEndpoint(
 ):
     '''Use an Application Load Balancer as a Global Accelerator Endpoint.
 
-    :exampleMetadata: fixture=_generated
+    :exampleMetadata: infused
 
     Example::
 
-        # The code below shows an example of how to instantiate this type.
-        # The values are placeholders you should change.
-        import aws_cdk.aws_elasticloadbalancingv2 as elbv2
-        import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+        # alb: elbv2.ApplicationLoadBalancer
+        # listener: globalaccelerator.Listener
         
-        # application_load_balancer is of type ApplicationLoadBalancer
         
-        application_load_balancer_endpoint = globalaccelerator_endpoints.ApplicationLoadBalancerEndpoint(application_load_balancer,
-            preserve_client_ip=False,
-            weight=123
+        listener.add_endpoint_group("Group",
+            endpoints=[
+                ga_endpoints.ApplicationLoadBalancerEndpoint(alb,
+                    weight=128,
+                    preserve_client_ip=True
+                )
+            ]
         )
     '''
 
@@ -108,17 +109,21 @@ class ApplicationLoadBalancerEndpointOptions:
         :param preserve_client_ip: Forward the client IP address in an ``X-Forwarded-For`` header. GlobalAccelerator will create Network Interfaces in your VPC in order to preserve the client IP address. Client IP address preservation is supported only in specific AWS Regions. See the GlobalAccelerator Developer Guide for a list. Default: true if available
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
 
-        :exampleMetadata: fixture=_generated
+        :exampleMetadata: infused
 
         Example::
 
-            # The code below shows an example of how to instantiate this type.
-            # The values are placeholders you should change.
-            import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+            # alb: elbv2.ApplicationLoadBalancer
+            # listener: globalaccelerator.Listener
             
-            application_load_balancer_endpoint_options = globalaccelerator_endpoints.ApplicationLoadBalancerEndpointOptions(
-                preserve_client_ip=False,
-                weight=123
+            
+            listener.add_endpoint_group("Group",
+                endpoints=[
+                    ga_endpoints.ApplicationLoadBalancerEndpoint(alb,
+                        weight=128,
+                        preserve_client_ip=True
+                    )
+                ]
             )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
@@ -172,19 +177,20 @@ class CfnEipEndpoint(
 ):
     '''Use an EC2 Instance as a Global Accelerator Endpoint.
 
-    :exampleMetadata: fixture=_generated
+    :exampleMetadata: infused
 
     Example::
 
-        # The code below shows an example of how to instantiate this type.
-        # The values are placeholders you should change.
-        import aws_cdk.aws_ec2 as ec2
-        import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+        # listener: globalaccelerator.Listener
+        # eip: ec2.CfnEIP
         
-        # cfn_eIP is of type CfnEIP
         
-        cfn_eip_endpoint = globalaccelerator_endpoints.CfnEipEndpoint(cfn_eIP,
-            weight=123
+        listener.add_endpoint_group("Group",
+            endpoints=[
+                ga_endpoints.CfnEipEndpoint(eip,
+                    weight=128
+                )
+            ]
         )
     '''
 
@@ -228,16 +234,20 @@ class CfnEipEndpointProps:
 
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
 
-        :exampleMetadata: fixture=_generated
+        :exampleMetadata: infused
 
         Example::
 
-            # The code below shows an example of how to instantiate this type.
-            # The values are placeholders you should change.
-            import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+            # listener: globalaccelerator.Listener
+            # eip: ec2.CfnEIP
             
-            cfn_eip_endpoint_props = globalaccelerator_endpoints.CfnEipEndpointProps(
-                weight=123
+            
+            listener.add_endpoint_group("Group",
+                endpoints=[
+                    ga_endpoints.CfnEipEndpoint(eip,
+                        weight=128
+                    )
+                ]
             )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
@@ -274,20 +284,21 @@ class InstanceEndpoint(
 ):
     '''Use an EC2 Instance as a Global Accelerator Endpoint.
 
-    :exampleMetadata: fixture=_generated
+    :exampleMetadata: infused
 
     Example::
 
-        # The code below shows an example of how to instantiate this type.
-        # The values are placeholders you should change.
-        import aws_cdk.aws_ec2 as ec2
-        import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+        # listener: globalaccelerator.Listener
+        # instance: ec2.Instance
         
-        # instance is of type Instance
         
-        instance_endpoint = globalaccelerator_endpoints.InstanceEndpoint(instance,
-            preserve_client_ip=False,
-            weight=123
+        listener.add_endpoint_group("Group",
+            endpoints=[
+                ga_endpoints.InstanceEndpoint(instance,
+                    weight=128,
+                    preserve_client_ip=True
+                )
+            ]
         )
     '''
 
@@ -341,17 +352,21 @@ class InstanceEndpointProps:
         :param preserve_client_ip: Forward the client IP address. GlobalAccelerator will create Network Interfaces in your VPC in order to preserve the client IP address. Client IP address preservation is supported only in specific AWS Regions. See the GlobalAccelerator Developer Guide for a list. Default: true if available
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
 
-        :exampleMetadata: fixture=_generated
+        :exampleMetadata: infused
 
         Example::
 
-            # The code below shows an example of how to instantiate this type.
-            # The values are placeholders you should change.
-            import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+            # listener: globalaccelerator.Listener
+            # instance: ec2.Instance
             
-            instance_endpoint_props = globalaccelerator_endpoints.InstanceEndpointProps(
-                preserve_client_ip=False,
-                weight=123
+            
+            listener.add_endpoint_group("Group",
+                endpoints=[
+                    ga_endpoints.InstanceEndpoint(instance,
+                        weight=128,
+                        preserve_client_ip=True
+                    )
+                ]
             )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
@@ -409,13 +424,8 @@ class NetworkLoadBalancerEndpoint(
 
     Example::
 
-        # Example automatically generated from non-compiling source. May contain errors.
-        import aws_cdk.aws_globalaccelerator as globalaccelerator
-        import aws_cdk.aws_globalaccelerator_endpoints as ga_endpoints
-        import aws_cdk.aws_elasticloadbalancingv2 as elbv2
-        
         # Create an Accelerator
-        accelerator = globalaccelerator.Accelerator(stack, "Accelerator")
+        accelerator = globalaccelerator.Accelerator(self, "Accelerator")
         
         # Create a Listener
         listener = accelerator.add_listener("Listener",
@@ -424,10 +434,10 @@ class NetworkLoadBalancerEndpoint(
         )
         
         # Import the Load Balancers
-        nlb1 = elbv2.NetworkLoadBalancer.from_network_load_balancer_attributes(stack, "NLB1",
+        nlb1 = elbv2.NetworkLoadBalancer.from_network_load_balancer_attributes(self, "NLB1",
             load_balancer_arn="arn:aws:elasticloadbalancing:us-west-2:111111111111:loadbalancer/app/my-load-balancer1/e16bef66805b"
         )
-        nlb2 = elbv2.NetworkLoadBalancer.from_network_load_balancer_attributes(stack, "NLB2",
+        nlb2 = elbv2.NetworkLoadBalancer.from_network_load_balancer_attributes(self, "NLB2",
             load_balancer_arn="arn:aws:elasticloadbalancing:ap-south-1:111111111111:loadbalancer/app/my-load-balancer2/5513dc2ea8a1"
         )
         
@@ -483,16 +493,20 @@ class NetworkLoadBalancerEndpointProps:
 
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
 
-        :exampleMetadata: fixture=_generated
+        :exampleMetadata: infused
 
         Example::
 
-            # The code below shows an example of how to instantiate this type.
-            # The values are placeholders you should change.
-            import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+            # nlb: elbv2.NetworkLoadBalancer
+            # listener: globalaccelerator.Listener
             
-            network_load_balancer_endpoint_props = globalaccelerator_endpoints.NetworkLoadBalancerEndpointProps(
-                weight=123
+            
+            listener.add_endpoint_group("Group",
+                endpoints=[
+                    ga_endpoints.NetworkLoadBalancerEndpoint(nlb,
+                        weight=128
+                    )
+                ]
             )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
